@@ -29,10 +29,10 @@ class Chatter(BaseClient):
                 if  segment['type'] == 'Text':
                     print("{}".format(segment['text'].replace('\n',' ')))
     
-    def post_chatter_message(self, messageText, obj=None):
+    def post_chatter_message(self, messageText, obj=None, mention_ids=[]):
         if obj is None:
-            return self.client.chatter_post(messageText)
+            return self.client.chatter_post(messageText, mention_ids)
         else:
-            return self.client.chatter_on_object(messageText, obj)
+            return self.client.chatter_on_object(messageText, obj, mention_ids)
         
         
\ No newline at end of file
